@@ -1,4 +1,4 @@
-import argparse
+import configargparse
 import asyncio
 import logging
 import sys
@@ -26,25 +26,30 @@ def on_message(client, userdata, msg):
     print(msg.topic + " " + str(msg.payload))
 
 
-async def send_loop(client, ess, once=False, interval_seconds=10):
+async def send_loop(ess, mqtt_client=None, graphite_client=None, once=False, interval_seconds=10, common_divisor=1):
     logger.info("starting send loop")
+    i=0
     while True:
         if not once:
             await asyncio.sleep(1)
         home = await ess.get_state("home")
-        common = await ess.get_state("common")
         for key in home:
             for key2 in home[key]:
                 try:
-                    await client.publish("ess/home/" + key + "/" + key2, home[key][key2])
-                except:
-                    pass
-        for key in common:
-            for key2 in common[key]:
-                try:
-                    await client.publish("ess/common/" + key + "/" + key2, common[key][key2])
+                    await mqtt_client.publish("ess/home/" + key + "/" + key2, home[key][key2])
                 except:
+                    logger.exception("exception while sending to mqtt")
                     pass
+        if i % common_divisor == 0:
+            common = await ess.get_state("common")
+            for key in common:
+                for key2 in common[key]:
+                    try:
+                        await mqtt_client.publish("ess/common/" + key + "/" + key2, common[key][key2])
+                    except:
+                        logger.exception("exception while sending to mqtt")
+                        pass
+        i+=1
         if once:
             break
         await asyncio.sleep(interval_seconds - 1)
@@ -57,7 +62,12 @@ def main(arguments=None):
 
 
 async def _main(arguments=None):
-    parser = argparse.ArgumentParser(prog='pyess', description='Command line interface for pyess')
+
+    parser = configargparse.ArgumentParser(prog='essmqtt', description='Mqtt connector for pyess',
+                                           add_config_file_help=True,
+                                           default_config_files=['/etc/essmqtt.conf', '~/.essmqtt.conf'],
+                                           args_for_setting_config_path=["--config_file"],)
+
     parser.add_argument(
         '--loglevel', default='info', help='Log level',
         choices=['debug', 'info', 'warning', 'error', 'critical'],
@@ -70,6 +80,7 @@ async def _main(arguments=None):
     parser.add_argument("--mqtt_user", default=None, help="mqtt user")
     parser.add_argument("--ess_host", default=None, help="hostname or IP of mqtt host (discover via mdns if not set)")
     parser.add_argument("--once", default=False, type=bool, help="no loop, only one pass")
+    parser.add_argument("--common_divisor", default=1, type=int, help="multiply interval_seconds for values below 'common' by this factor")
     parser.add_argument("--interval_seconds", default=10, type=int, help="update interval (default: 10 seconds)")
 
     args = parser.parse_args(arguments)
@@ -114,17 +125,26 @@ async def _main(arguments=None):
                 except ValueError:
                     logger.warning(f"ignoring incompatible value {msg} for switching")
 
-
-    async with Client(args.mqtt_server, port=args.mqtt_port, logger=logger, username=args.mqtt_user,
+    if args.mqtt_server is not None:
+        async with Client(args.mqtt_server, port=args.mqtt_port, logger=logger, username=args.mqtt_user,
                       password=args.mqtt_password) as client:
+            # seems that a leading slash is frowned upon in mqtt, but we keep this for backwards compatibility
+            await client.subscribe('/ess/control/#')
+            asyncio.create_task(handle_control(client, switch_winter, "/ess/control/winter_mode"))
+            asyncio.create_task(handle_control(client, switch_fastcharge, "/ess/control/fastcharge"))
+            asyncio.create_task(handle_control(client, switch_active, "/ess/control/active"))
 
-        await client.subscribe('/ess/control/#')
-        asyncio.create_task(handle_control(client, switch_winter, "/ess/control/winter_mode"))
-        asyncio.create_task(handle_control(client, switch_fastcharge, "/ess/control/fastcharge"))
-        asyncio.create_task(handle_control(client, switch_active, "/ess/control/active"))
+            # also subscribe without leading slash for better style
+            await client.subscribe('ess/control/#')
+            asyncio.create_task(handle_control(client, switch_winter, "ess/control/winter_mode"))
+            asyncio.create_task(handle_control(client, switch_fastcharge, "ess/control/fastcharge"))
+            asyncio.create_task(handle_control(client, switch_active, "ess/control/active"))
 
-        await send_loop(client, ess, once=args.once, interval_seconds=args.interval_seconds)
+            await send_loop(ess, client, once=args.once, interval_seconds=args.interval_seconds,
+                            common_divisor=args.common_divisor)
 
+    else:
+        pass
 
 if __name__ == "__main__":
     main(sys.argv[1:])
